@@ -3,9 +3,9 @@ Crop - Crop a given size from one or multiple images.
 Crop is part of GNU Astronomy Utilities (Gnuastro) package.
 
 Original author:
-     Mohammad Akhlaghi <akhlaghi@gnu.org>
+     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2015, Free Software Foundation, Inc.
+Copyright (C) 2015-2018, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -35,6 +35,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gnuastro/fits.h>
 #include <gnuastro/blank.h>
 #include <gnuastro/polygon.h>
+#include <gnuastro/pointer.h>
 
 #include <gnuastro-internal/timing.h>
 #include <gnuastro-internal/checkset.h>
@@ -449,12 +450,14 @@ onecrop_name(struct onecropparams *crp)
       if(p->name)
         {
           strarr=p->name;
-          asprintf(&crp->name, "%s%s%s", cp->output, strarr[crp->out_ind],
-                   p->suffix);
+          if( asprintf(&crp->name, "%s%s%s", cp->output, strarr[crp->out_ind],
+                       p->suffix)<0 )
+            error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
         }
       else
-        asprintf(&crp->name, "%s%zu%s", cp->output, crp->out_ind+1,
-                 p->suffix);
+        if( asprintf(&crp->name, "%s%zu%s", cp->output, crp->out_ind+1,
+                     p->suffix)<0 )
+          error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
 
       /* Make sure the file doesn't exist. */
       gal_checkset_writable_remove(crp->name, 0, cp->dontdelete);
@@ -694,7 +697,16 @@ onecrop_make_array(struct onecropparams *crp, long *fpixel_i,
 
 
 /* The starting and ending points are set in the onecropparams structure
-   for one crop from one image. Crop that region out of the input. */
+   for one crop from one image. Crop that region out of the input.
+
+   On`basekeyname': To be safe, GCC 8.1 (and persumably later versions)
+   assumes that we are writing the full statically allocated space into
+   `regioinkey'! So it prints a warning that you may be writing outside the
+   allocated space! With these variables, we are ultimately just writing
+   the file counters, so we can never (with current techologies!!!) exceed
+   `FLEN_KEYWORD' (which is 75 characters). To avoid compiler warnings, we
+   are just removing a few characters (`FLEN_KEYWORD-5') to allow the
+   suffix and remove the warnings. */
 void
 onecrop(struct onecropparams *crp)
 {
@@ -703,9 +715,9 @@ onecrop(struct onecropparams *crp)
 
   void *array;
   int status=0, anynul=0;
-  char basename[FLEN_KEYWORD];
   fitsfile *ifp=crp->infits, *ofp;
-  gal_fits_list_key_t *headers=NULL;
+  char basekeyname[FLEN_KEYWORD-5];     /* `-5': avoid gcc 8.1+ warnings! */
+  gal_fits_list_key_t *headers=NULL;    /* See above comment for more.    */
   size_t i, j, cropsize=1, ndim=img->ndim;
   char region[FLEN_VALUE], regionkey[FLEN_KEYWORD];
   long fpixel_o[MAXDIM], lpixel_o[MAXDIM], inc[MAXDIM];
@@ -741,7 +753,7 @@ onecrop(struct onecropparams *crp)
          the desired pixels onto it. */
       status=0;
       for(i=0;i<ndim;++i) cropsize *= ( lpixel_i[i] - fpixel_i[i] + 1 );
-      array=gal_data_malloc_array(p->type, cropsize, __func__, "array");
+      array=gal_pointer_allocate(p->type, cropsize, 0, __func__, "array");
       if(fits_read_subset(ifp, gal_fits_type_to_datatype(p->type),
                           fpixel_i, lpixel_i, inc, p->bitnul, array,
                           &anynul, &status))
@@ -787,9 +799,9 @@ onecrop(struct onecropparams *crp)
 
       /* A section has been added to the cropped image from this input
          image, so save the information of this image. */
-      sprintf(basename, "ICF%zu", crp->numimg);
-      gal_fits_key_write_filename(basename, img->name, &headers);
-      sprintf(regionkey, "%sPIX", basename);
+      sprintf(basekeyname, "ICF%zu", crp->numimg);
+      gal_fits_key_write_filename(basekeyname, img->name, &headers);
+      sprintf(regionkey, "%sPIX", basekeyname);
       gal_fits_key_list_add_end(&headers, GAL_TYPE_STRING, regionkey,
                                 0, region, 0, "Range of pixels used for "
                                 "this output.", 0, NULL);
@@ -868,7 +880,7 @@ onecrop_center_filled(struct onecropparams *crp)
   */
 
   /* Allocate the array and read in the pixels. */
-  array=gal_data_malloc_array(type, size, __func__, "array");
+  array=gal_pointer_allocate(type, size, 0, __func__, "array");
   if( fits_read_subset(ofp, gal_fits_type_to_datatype(type), fpixel, lpixel,
                        inc, p->bitnul, array, &anynul, &status) )
     gal_fits_io_error(status, NULL);
