@@ -3,9 +3,9 @@ MakeCatalog - Make a catalog from an input and labeled image.
 MakeCatalog is part of GNU Astronomy Utilities (Gnuastro) package.
 
 Original author:
-     Mohammad Akhlaghi <akhlaghi@gnu.org>
+     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016, Free Software Foundation, Inc.
+Copyright (C) 2016-2018, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -32,38 +32,12 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 struct argp_option program_options[] =
   {
     /* Input options. */
-    {
-      "objectsfile",
-      UI_KEY_OBJECTSFILE,
-      "STR",
-      0,
-      "Image containing object/detection labels.",
-      GAL_OPTIONS_GROUP_INPUT,
-      &p->objectsfile,
-      GAL_TYPE_STRING,
-      GAL_OPTIONS_RANGE_ANY,
-      GAL_OPTIONS_NOT_MANDATORY,
-      GAL_OPTIONS_NOT_SET
-    },
-    {
-      "objectshdu",
-      UI_KEY_OBJECTSHDU,
-      "STR",
-      0,
-      "Object image extension name or number.",
-      GAL_OPTIONS_GROUP_INPUT,
-      &p->objectshdu,
-      GAL_TYPE_STRING,
-      GAL_OPTIONS_RANGE_ANY,
-      GAL_OPTIONS_MANDATORY,
-      GAL_OPTIONS_NOT_SET
-    },
     {
       "clumpsfile",
       UI_KEY_CLUMPSFILE,
       "STR",
       0,
-      "Image containing clump labels.",
+      "Dataset containing clump labels.",
       GAL_OPTIONS_GROUP_INPUT,
       &p->clumpsfile,
       GAL_TYPE_STRING,
@@ -76,7 +50,7 @@ struct argp_option program_options[] =
       UI_KEY_CLUMPSHDU,
       "STR",
       0,
-      "Clump image extension name or number.",
+      "Clump labels extension name or number.",
       GAL_OPTIONS_GROUP_INPUT,
       &p->clumpshdu,
       GAL_TYPE_STRING,
@@ -85,11 +59,37 @@ struct argp_option program_options[] =
       GAL_OPTIONS_NOT_SET
     },
     {
-      "skyfile",
-      UI_KEY_SKYFILE,
+      "valuesfile",
+      UI_KEY_VALUESFILE,
       "STR",
       0,
-      "Image containing sky values.",
+      "Values/brightness dataset.",
+      GAL_OPTIONS_GROUP_INPUT,
+      &p->valuesfile,
+      GAL_TYPE_STRING,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
+    {
+      "valueshdu",
+      UI_KEY_VALUESHDU,
+      "STR",
+      0,
+      "Name or number of extension containing values.",
+      GAL_OPTIONS_GROUP_INPUT,
+      &p->valueshdu,
+      GAL_TYPE_STRING,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
+    {
+      "insky",
+      UI_KEY_INSKY,
+      "STR/FLT",
+      0,
+      "Input Sky value or dataset.",
       GAL_OPTIONS_GROUP_INPUT,
       &p->skyfile,
       GAL_TYPE_STRING,
@@ -107,15 +107,28 @@ struct argp_option program_options[] =
       &p->skyhdu,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
-      GAL_OPTIONS_MANDATORY,
+      GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
     {
-      "stdfile",
-      UI_KEY_STDFILE,
-      "STR",
+      "subtractsky",
+      UI_KEY_SUBTRACTSKY,
       0,
-      "Image containing sky STD values.",
+      0,
+      "Subtract the Sky dataset from the values.",
+      GAL_OPTIONS_GROUP_INPUT,
+      &p->subtractsky,
+      GAL_OPTIONS_NO_ARG_TYPE,
+      GAL_OPTIONS_RANGE_0_OR_1,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
+    {
+      "instd",
+      UI_KEY_INSTD,
+      "STR/FLT",
+      0,
+      "Sky standard deviation value or dataset.",
       GAL_OPTIONS_GROUP_INPUT,
       &p->stdfile,
       GAL_TYPE_STRING,
@@ -128,12 +141,25 @@ struct argp_option program_options[] =
       UI_KEY_STDHDU,
       "STR",
       0,
-      "Sky image extension name or number.",
+      "Sky STD extension name or number.",
       GAL_OPTIONS_GROUP_INPUT,
       &p->stdhdu,
       GAL_TYPE_STRING,
       GAL_OPTIONS_RANGE_ANY,
-      GAL_OPTIONS_MANDATORY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET
+    },
+    {
+      "variance",
+      UI_KEY_VARIANCE,
+      0,
+      0,
+      "STD input dataset is actually variance.",
+      GAL_OPTIONS_GROUP_INPUT,
+      &p->variance,
+      GAL_OPTIONS_NO_ARG_TYPE,
+      GAL_OPTIONS_RANGE_0_OR_1,
+      GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
     {
@@ -149,36 +175,36 @@ struct argp_option program_options[] =
       GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
+
+
+
+    /* Output. */
     {
-      "skysubtracted",
-      UI_KEY_SKYSUBTRACTED,
+      "clumpscat",
+      UI_KEY_CLUMPSCAT,
       0,
       0,
-      "Input is already sky subtracted (for S/N).",
-      GAL_OPTIONS_GROUP_INPUT,
-      &p->skysubtracted,
+      "Make a clumps catalog also.",
+      GAL_OPTIONS_GROUP_OUTPUT,
+      &p->clumpscat,
       GAL_OPTIONS_NO_ARG_TYPE,
       GAL_OPTIONS_RANGE_0_OR_1,
       GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
     {
-      "threshold",
-      UI_KEY_THRESHOLD,
-      "FLT",
+      "noclumpsort",
+      UI_KEY_NOCLUMPSORT,
       0,
-      "Use pixels more than this multiple of STD.",
-      GAL_OPTIONS_GROUP_INPUT,
-      &p->threshold,
-      GAL_TYPE_FLOAT32,
-      GAL_OPTIONS_RANGE_ANY,
+      0,
+      "Don't sort the clumps catalog by ID.",
+      GAL_OPTIONS_GROUP_OUTPUT,
+      &p->noclumpsort,
+      GAL_OPTIONS_NO_ARG_TYPE,
+      GAL_OPTIONS_RANGE_0_OR_1,
       GAL_OPTIONS_NOT_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
-
-
-
-    /* Output. */
     {
       "sfmagnsigma",
       UI_KEY_SFMAGNSIGMA,
@@ -307,6 +333,20 @@ struct argp_option program_options[] =
       GAL_OPTIONS_MANDATORY,
       GAL_OPTIONS_NOT_SET
     },
+    {
+      "checkupperlimit",
+      UI_KEY_CHECKUPPERLIMIT,
+      "INT[,INT]",
+      0,
+      "Check random distribution for one label.",
+      UI_GROUP_UPPERLIMIT,
+      &p->checkupperlimit,
+      GAL_TYPE_STRING,
+      GAL_OPTIONS_RANGE_GT_0,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+      ui_check_upperlimit
+    },
 
 
 
@@ -674,6 +714,20 @@ struct argp_option program_options[] =
       GAL_OPTIONS_NOT_SET,
       ui_column_codes_ll
     },
+    {
+      "brightnesserr",
+      UI_KEY_BRIGHTNESSERR,
+      0,
+      0,
+      "Error (1-sigma) in measuring brightness.",
+      UI_GROUP_COLUMNS_BRIGHTNESS,
+      0,
+      GAL_TYPE_INVALID,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+      ui_column_codes_ll
+    },
     {
       "clumpbrightness",
       UI_KEY_CLUMPSBRIGHTNESS,
@@ -702,6 +756,34 @@ struct argp_option program_options[] =
       GAL_OPTIONS_NOT_SET,
       ui_column_codes_ll
     },
+    {
+      "mean",
+      UI_KEY_MEAN,
+      0,
+      0,
+      "Mean of values in object/clump.",
+      UI_GROUP_COLUMNS_BRIGHTNESS,
+      0,
+      GAL_TYPE_INVALID,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+      ui_column_codes_ll
+    },
+    {
+      "median",
+      UI_KEY_MEDIAN,
+      0,
+      0,
+      "Median of values in object/clump.",
+      UI_GROUP_COLUMNS_BRIGHTNESS,
+      0,
+      GAL_TYPE_INVALID,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+      ui_column_codes_ll
+    },
     {
       "magnitude",
       UI_KEY_MAGNITUDE,
@@ -772,6 +854,62 @@ struct argp_option program_options[] =
       GAL_OPTIONS_NOT_SET,
       ui_column_codes_ll
     },
+    {
+      "upperlimitonesigma",
+      UI_KEY_UPPERLIMITONESIGMA,
+      0,
+      0,
+      "Upper-limit one sigma value.",
+      UI_GROUP_COLUMNS_BRIGHTNESS,
+      0,
+      GAL_TYPE_INVALID,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+      ui_column_codes_ll
+    },
+    {
+      "upperlimitsigma",
+      UI_KEY_UPPERLIMITSIGMA,
+      0,
+      0,
+      "Place in random distribution (sigma multiple).",
+      UI_GROUP_COLUMNS_BRIGHTNESS,
+      0,
+      GAL_TYPE_INVALID,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+      ui_column_codes_ll
+    },
+    {
+      "upperlimitquantile",
+      UI_KEY_UPPERLIMITQUANTILE,
+      0,
+      0,
+      "Quantile in random distribution (max 1).",
+      UI_GROUP_COLUMNS_BRIGHTNESS,
+      0,
+      GAL_TYPE_INVALID,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+      ui_column_codes_ll
+    },
+    {
+      "upperlimitskew",
+      UI_KEY_UPPERLIMITSKEW,
+      0,
+      0,
+      "(Mean-Median)/STD of random distribution.",
+      UI_GROUP_COLUMNS_BRIGHTNESS,
+      0,
+      GAL_TYPE_INVALID,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+      ui_column_codes_ll
+    },
     {
       "riverave",
       UI_KEY_RIVERAVE,
@@ -833,7 +971,7 @@ struct argp_option program_options[] =
       UI_KEY_STD,
       0,
       0,
-      "Average Sky standard deviation.",
+      "Average Sky standard deviation under label.",
       UI_GROUP_COLUMNS_BRIGHTNESS,
       0,
       GAL_TYPE_INVALID,
@@ -846,7 +984,7 @@ struct argp_option program_options[] =
 
 
 
-    /* Morphology/shapre related columns. */
+    /* Morphology/shape related columns. */
     {
       0, 0, 0, 0,
       "Morphology/shape related columns",
@@ -871,7 +1009,7 @@ struct argp_option program_options[] =
       UI_KEY_AREA,
       0,
       0,
-      "Number of pixels in clump or object.",
+      "Number of non-blank valued pixels.",
       UI_GROUP_COLUMNS_MORPHOLOGY,
       0,
       GAL_TYPE_INVALID,
@@ -885,7 +1023,7 @@ struct argp_option program_options[] =
       UI_KEY_CLUMPSAREA,
       0,
       0,
-      "Sum of all clump areas in an object.",
+      "Non-blank area covered by clumps.",
       UI_GROUP_COLUMNS_MORPHOLOGY,
       0,
       GAL_TYPE_INVALID,
@@ -899,7 +1037,21 @@ struct argp_option program_options[] =
       UI_KEY_WEIGHTAREA,
       0,
       0,
-      "Area used for flux weighted positions.",
+      "Area used for value weighted positions.",
+      UI_GROUP_COLUMNS_MORPHOLOGY,
+      0,
+      GAL_TYPE_INVALID,
+      GAL_OPTIONS_RANGE_ANY,
+      GAL_OPTIONS_NOT_MANDATORY,
+      GAL_OPTIONS_NOT_SET,
+      ui_column_codes_ll
+    },
+    {
+      "geoarea",
+      UI_KEY_GEOAREA,
+      0,
+      0,
+      "Area labled region (irrespective of value).",
       UI_GROUP_COLUMNS_MORPHOLOGY,
       0,
       GAL_TYPE_INVALID,
