@@ -3,9 +3,9 @@ multidim -- Functions for multi-dimensional operations.
 This is part of GNU Astronomy Utilities (Gnuastro) package.
 
 Original author:
-     Mohammad Akhlaghi <akhlaghi@gnu.org>
+     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2017, Free Software Foundation, Inc.
+Copyright (C) 2017-2018, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -26,6 +26,7 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 /* Include other headers if necessary here. Note that other header files
    must be included before the C++ preparations below */
 #include <gnuastro/data.h>
+#include <gnuastro/blank.h>
 
 /* C++ Preparations */
 #undef __BEGIN_C_DECLS
@@ -52,6 +53,9 @@ __BEGIN_C_DECLS  /* From C++ preparations */
 size_t
 gal_dimension_total_size(size_t ndim, size_t *dsize);
 
+int
+gal_dimension_is_different(gal_data_t *first, gal_data_t *second);
+
 size_t *
 gal_dimension_increment(size_t ndim, size_t *dsize);
 
