@@ -2,9 +2,9 @@
 Function to parse options and configuration file values.
 
 Original author:
-     Mohammad Akhlaghi <akhlaghi@gnu.org>
+     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2017, Free Software Foundation, Inc.
+Copyright (C) 2017-2018, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -34,6 +34,8 @@ along with Gnuastro. If not, see <http://www.gnu.org/licenses/>.
 #include <gnuastro/data.h>
 #include <gnuastro/table.h>
 #include <gnuastro/blank.h>
+#include <gnuastro/threads.h>
+#include <gnuastro/pointer.h>
 #include <gnuastro/arithmetic.h>
 
 #include <gnuastro-internal/timing.h>
@@ -178,35 +180,60 @@ void *
 gal_options_check_version(struct argp_option *option, char *arg,
                           char *filename, size_t lineno, void *junk)
 {
-  /* Check if the given value is different from this version. */
-  if( strcmp(arg, PACKAGE_VERSION) )
-    {
-      /* Print an error message and abort.  */
-      error_at_line(EXIT_FAILURE, 0, filename, lineno, "version mis-match: "
-                    "you are running GNU Astronomy Utilities (Gnuastro) "
-                    "version `%s'. However, the `onlyversion' option is set "
-                    "to version `%s'.\n\n"
-                    "This was probably done for reproducibility. Therefore, "
-                    "manually removing, or changing, the option value might "
-                    "produce errors or unexpected results. It is thus "
-                    "strongly advised to build Gnuastro %s and re-run this "
-                    "command/script.\n\n"
-                    "You can download previously released tar-balls from the "
-                    "following URLs respectively:\n\n"
-                    "    Stable (version format: X.Y):      "
-                    "http://ftpmirror.gnu.org/gnuastro\n"
-                    "    Alpha  (version format: X.Y.A-B):  "
-                    "http://alpha.gnu.org/gnu/gnuastro\n\n"
-                    "Alternatively, you can clone Gnuastro, checkout the "
-                    "respective commit (from the version number), then "
-                    "bootstrap and build it. Please run the following "
-                    "command for more information:\n\n"
-                    "    $ info gnuastro \"Version controlled source\"\n",
-                    PACKAGE_VERSION, arg, arg);
+  char *str;
 
-      /* Just to avoid compiler warnings for unused variables. The program
-         will never reach this point! */
-      arg=filename=NULL; lineno=0; option=NULL; junk=NULL;
+  /* First see if we are reading or writing. */
+  if(lineno==-1)
+    {
+      /* `PACKAGE_VERSION' is a static/literal string, but the pointer
+         returned by this function will be freed, so we must allocate space
+         for it.
+
+         We didn't allocate and give this option a value when we read it
+         because it is redundant and much more likely for the option to
+         just be present (for a check in a reproduction pipeline for
+         example) than for it to be printed. So we don't want to waste
+         resources in allocating a redundant value. */
+      gal_checkset_allocate_copy(PACKAGE_VERSION, &str);
+      return str;
+    }
+
+  /* Check if the given value is different from this version. */
+  else
+    {
+      if(arg==NULL)
+        error(EXIT_FAILURE, 0, "%s: a bug! Please contact us at %s to fix "
+              "the problem. The value to `arg' is NULL", __func__,
+              PACKAGE_BUGREPORT);
+      else if( strcmp(arg, PACKAGE_VERSION) )
+        {
+          /* Print an error message and abort.  */
+          error_at_line(EXIT_FAILURE, 0, filename, lineno, "version "
+                        "mis-match: you are running GNU Astronomy Utilities "
+                        "(Gnuastro) version `%s'. However, the `onlyversion' "
+                        "option is set to version `%s'.\n\n"
+                        "This was probably done for reproducibility. "
+                        "Therefore, manually removing, or changing, the "
+                        "option value might produce errors or unexpected "
+                        "results. It is thus strongly advised to build "
+                        "Gnuastro %s and re-run this command/script.\n\n"
+                        "You can download previously released tar-balls "
+                        "from the following URLs respectively:\n\n"
+                        "    Stable (version format: X.Y):      "
+                        "http://ftpmirror.gnu.org/gnuastro\n"
+                        "    Alpha  (version format: X.Y.A-B):  "
+                        "http://alpha.gnu.org/gnu/gnuastro\n\n"
+                        "Alternatively, you can clone Gnuastro, checkout the "
+                        "respective commit (from the version number), then "
+                        "bootstrap and build it. Please run the following "
+                        "command for more information:\n\n"
+                        "    $ info gnuastro \"Version controlled source\"\n",
+                        PACKAGE_VERSION, arg, arg);
+
+          /* Just to avoid compiler warnings for unused variables. The program
+             will never reach this point! */
+          arg=filename=NULL; lineno=0; option=NULL; junk=NULL;
+        }
     }
   return NULL;
 }
@@ -220,6 +247,7 @@ gal_options_print_citation(struct argp_option *option, char *arg,
                            char *filename, size_t lineno, void *pa)
 {
   struct gal_options_common_params *cp=(struct gal_options_common_params *)pa;
+  char *gnuastro_acknowledgement;
   char *gnuastro_bibtex=
     "Gnuastro package/infrastructure\n"
     "-------------------------------\n"
@@ -248,17 +276,37 @@ gal_options_print_citation(struct argp_option *option, char *arg,
   /* Print the statements. */
   printf("\nThank you for using %s (%s) %s.\n\n", cp->program_name,
          PACKAGE_NAME, PACKAGE_VERSION);
-  printf("Citations are vital for the continued work on Gnuastro.\n\n"
-         "Please cite these BibTeX record(s) in your paper(s).\n"
-         "(don't forget to also include the version as shown above)\n\n"
-         "%s\n\n",
-         gnuastro_bibtex);
+  printf("Citations and acknowledgement are vital for the continued "
+         "work on Gnuastro.\n\n"
+         "Please cite the following record(s) and add the acknowledgement "
+         "statement below in your work to support us. Please note that "
+         "different Gnuastro programs may have different corresponding "
+         "papers. Hence, please check all the programs you used. Don't "
+         "forget to also include the version as shown above for "
+         "reproducibility.\n\n"
+         "%s\n\n", gnuastro_bibtex);
 
 
   /* Only print the citation for the program if one exists. */
   if(cp->program_bibtex[0]!='\0') printf("%s\n\n", cp->program_bibtex);
 
 
+  /* Notice for acknowledgements. */
+  if( asprintf(&gnuastro_acknowledgement,
+               "Acknowledgement\n"
+               "---------------\n"
+               "This work was partly done using GNU Astronomy Utilities "
+               "(Gnuastro, ascl.net/1801.009) version %s. Gnuastro is a "
+               "generic package for astronomical data manipulation and "
+               "analysis which was initially created and developed for "
+               "research funded by the Monbukagakusho (Japanese "
+               "government) scholarship and European Research Council "
+               "(ERC) advanced grant 339659-MUSICOS.", PACKAGE_VERSION)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
+  printf("%s\n", gnuastro_acknowledgement);
+  free(gnuastro_acknowledgement);
+
+
   /* Print a thank you message. */
   printf("                                               ,\n"
          "                                              {|'--.\n"
@@ -617,15 +665,15 @@ gal_options_parse_csv_strings_raw(char *string, char *filename, size_t lineno)
 
 /* `arg' is the value given to an option. It contains multiple strings
    separated by a comma (`,'). This function will parse `arg' and make a
-   `gal_data_t' that contains all the strings separately. The output
-   `gal_data_t' will be put in `option->value'. */
+   `gal_data_t' array of strings from it. The output `gal_data_t' will be
+   put in `option->value'. */
 void *
 gal_options_parse_csv_strings(struct argp_option *option, char *arg,
                               char *filename, size_t lineno, void *junk)
 {
-  int i;
   size_t nc;
-  char **strarr;
+  char *c, **strarr;
+  int i, has_space=0;
   gal_data_t *values;
   char *str, sstr[GAL_OPTIONS_STATIC_MEM_FOR_VALUES];
 
@@ -635,9 +683,25 @@ gal_options_parse_csv_strings(struct argp_option *option, char *arg,
       /* Set the pointer to the values dataset. */
       values = *(gal_data_t **)(option->value);
 
-      /* Write each string into the output string */
-      nc=0;
+      /* See if there are any space characters in the final string. */
       strarr=values->array;
+      for(i=0;i<values->size;++i)
+        if(has_space==0)
+        {
+          for(c=strarr[i];*c!='\0';++c)
+            if(*c==' ' || *c=='\t')
+              {
+                has_space=1;
+                break;
+              }
+        }
+
+      /* If there is a space, the string must start wth quotation marks. */
+      nc = has_space ? 1 : 0;
+      if(has_space) {sstr[0]='"'; sstr[1]='\0';}
+
+
+      /* Write each string into the output string */
       for(i=0;i<values->size;++i)
         {
           if( nc > GAL_OPTIONS_STATIC_MEM_FOR_VALUES-100 )
@@ -648,7 +712,11 @@ gal_options_parse_csv_strings(struct argp_option *option, char *arg,
                   GAL_OPTIONS_STATIC_MEM_FOR_VALUES);
           nc += sprintf(sstr+nc, "%s,", strarr[i]);
         }
-      sstr[nc-1]='\0';
+
+      /* If there was a space, we need a quotation mark at the end of the
+         string. */
+      if(has_space) { sstr[nc-1]='"'; sstr[nc]='\0'; }
+      else            sstr[nc-1]='\0';
 
       /* Copy the string into a dynamically allocated space, because it
          will be freed later.*/
@@ -676,7 +744,7 @@ gal_options_parse_csv_strings(struct argp_option *option, char *arg,
 
 
 /* Parse the given string into a series of size values (integers, stored as
-   an array of size_t). The ouput array will be stored in the `value'
+   an array of size_t). The output array will be stored in the `value'
    element of the option. The last element of the array is
    `GAL_BLANK_SIZE_T' to allow finding the number of elements within it
    later (similar to a string which terminates with a '\0' element). */
@@ -748,7 +816,8 @@ gal_options_parse_sizes_reverse(struct argp_option *option, char *arg,
       /* Write the values into an allocated size_t array and finish it with
          a `-1' so the total number can be found later.*/
       num=values->size;
-      array=gal_data_malloc_array(GAL_TYPE_SIZE_T, num+1, __func__, "array");
+      array=gal_pointer_allocate(GAL_TYPE_SIZE_T, num+1, 0, __func__,
+                                 "array");
       for(i=0;i<num;++i) array[num-1-i]=v[i];
       array[num] = GAL_BLANK_SIZE_T;
 
@@ -763,6 +832,65 @@ gal_options_parse_sizes_reverse(struct argp_option *option, char *arg,
 
 
 
+/* Parse options with values of a list of numbers. */
+void *
+gal_options_parse_csv_float64(struct argp_option *option, char *arg,
+                              char *filename, size_t lineno, void *junk)
+{
+  size_t i, nc;
+  double *darray;
+  gal_data_t *values;
+  char *str, sstr[GAL_OPTIONS_STATIC_MEM_FOR_VALUES];
+
+  /* We want to print the stored values. */
+  if(lineno==-1)
+    {
+      /* Set the pointer to the values dataset. */
+      values = *(gal_data_t **)(option->value);
+      darray=values->array;
+
+      /* Write each string into the output string */
+      nc=0;
+      for(i=0;i<values->size;++i)
+        {
+          if( nc > GAL_OPTIONS_STATIC_MEM_FOR_VALUES-100 )
+            error(EXIT_FAILURE, 0, "%s: a bug! please contact us at %s so we "
+                  "can address the problem. The number of necessary "
+                  "characters in the statically allocated string has become "
+                  "too close to %d", __func__, PACKAGE_BUGREPORT,
+                  GAL_OPTIONS_STATIC_MEM_FOR_VALUES);
+          nc += sprintf(sstr+nc, "%g,", darray[i]);
+        }
+      sstr[nc-1]='\0';
+
+      /* Copy the string into a dynamically allocated space, because it
+         will be freed later.*/
+      gal_checkset_allocate_copy(sstr, &str);
+      return str;
+    }
+
+  /* We want to read the user's string. */
+  else
+    {
+      /* If the option is already set, just return. */
+      if(option->set) return NULL;
+
+      /* Read the values. */
+      values=gal_options_parse_list_of_numbers(arg, filename, lineno);
+
+      /* Put the values into the option. */
+      *(gal_data_t **)(option->value) = values;
+
+      /* The return value is only for printing mode, so we can return
+         NULL after reading is complete. */
+      return NULL;
+    }
+}
+
+
+
+
+
 /* Two numbers must be provided as an argument. This function will read
    them as the sigma-clipping multiple and parameter and store the two in a
    2-element array. `option->value' must point to an already allocated
@@ -778,7 +906,8 @@ gal_options_read_sigma_clip(struct argp_option *option, char *arg,
   /* Caller wants to print the option values. */
   if(lineno==-1)
     {
-      asprintf(&str, "%g,%g", sigmaclip[0], sigmaclip[1]);
+      if( asprintf(&str, "%g,%g", sigmaclip[0], sigmaclip[1])<0 )
+        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
       return str;
     }
 
@@ -1524,12 +1653,14 @@ gal_options_parse_config_files(struct gal_options_common_params *cp)
           "`uint8' type", __func__, PACKAGE_BUGREPORT);
 
   /* The program's current directory configuration file. */
-  asprintf(&filename, ".%s/%s.conf", PACKAGE, cp->program_exec);
+  if( asprintf(&filename, ".%s/%s.conf", PACKAGE, cp->program_exec)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
   options_parse_file(filename, cp, 0);
   free(filename);
 
   /* Common options configuration file. */
-  asprintf(&filename, ".%s/%s.conf", PACKAGE, PACKAGE);
+  if( asprintf(&filename, ".%s/%s.conf", PACKAGE, PACKAGE)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
   options_parse_file(filename, cp, 0);
   free(filename);
 
@@ -1537,23 +1668,27 @@ gal_options_parse_config_files(struct gal_options_common_params *cp)
   home=options_get_home();
 
   /* The program's user-wide configuration file. */
-  asprintf(&filename, "%s/%s/%s.conf", home, USERCONFIG_DIR,
-           cp->program_exec);
+  if( asprintf(&filename, "%s/%s/%s.conf", home, USERCONFIG_DIR,
+               cp->program_exec)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
   options_parse_file(filename, cp, 0);
   free(filename);
 
   /* Common options user-wide configuration file. */
-  asprintf(&filename, "%s/%s/%s.conf", home, USERCONFIG_DIR, PACKAGE);
+  if( asprintf(&filename, "%s/%s/%s.conf", home, USERCONFIG_DIR, PACKAGE)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
   options_parse_file(filename, cp, 0);
   free(filename);
 
   /* The program's system-wide configuration file. */
-  asprintf(&filename, "%s/%s.conf", SYSCONFIG_DIR, cp->program_exec);
+  if( asprintf(&filename, "%s/%s.conf", SYSCONFIG_DIR, cp->program_exec)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
   options_parse_file(filename, cp, 0);
   free(filename);
 
   /* Common options system-wide configuration file. */
-  asprintf(&filename, "%s/%s.conf", SYSCONFIG_DIR, PACKAGE);
+  if( asprintf(&filename, "%s/%s.conf", SYSCONFIG_DIR, PACKAGE)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
   options_parse_file(filename, cp, 0);
   free(filename);
 }
@@ -1601,6 +1736,11 @@ gal_options_read_config_set(struct gal_options_common_params *cp)
 
   /* Abort if any of the mandatory options are not set. */
   gal_options_abort_if_mandatory_missing(cp);
+
+  /* If `numthreads' is 0, use the number of threads available to the
+     system. */
+  if(cp->numthreads==0)
+    cp->numthreads=gal_threads_number();
 }
 
 
@@ -1887,7 +2027,8 @@ options_print_all(struct gal_options_common_params *cp, char *dirname,
       gal_checkset_mkdir(dirname);
 
       /* Prepare the full filename: */
-      asprintf(&filename, "%s/%s.conf", dirname, cp->program_exec);
+      if( asprintf(&filename, "%s/%s.conf", dirname, cp->program_exec)<0 )
+        error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
 
       /* Remove the file if it already exists. */
       gal_checkset_writable_remove(filename, 0, 0);
@@ -2005,35 +2146,52 @@ gal_options_print_state(struct gal_options_common_params *cp)
         case GAL_OPTIONS_KEY_PRINTPARAMS:
         case GAL_OPTIONS_KEY_SETDIRCONF:
         case GAL_OPTIONS_KEY_SETUSRCONF:
+
+          /* Note that these options can have a value of 1 (enabled) or 0
+             (explicitly disabled). Therefore the printing should only be
+             done if they have a value of 1. This is why we have defined
+             the `OPTIONS_UINT8VAL' macro above. */
           sum += OPTIONS_UINT8VAL;
         }
-  if(sum>1)
-    error(EXIT_FAILURE, 0, "only one of the `printparams', `setdirconf' "
-          "and `setusrconf' options can be called in each run");
 
 
-  /* Print the required configuration files. Note that simply having a
-     non-NULL value is not enough. They can have a value of 1 or 0, and the
-     respective file should only be created if we have a value of 1. */
-  for(i=0; !gal_options_is_last(&cp->coptions[i]); ++i)
-    if(cp->coptions[i].set && OPTIONS_UINT8VAL)
-      switch(cp->coptions[i].key)
-        {
-        case GAL_OPTIONS_KEY_PRINTPARAMS:
-          options_print_all(cp, NULL, NULL);
-          break;
+  /* See if the values should be printed and if so, where. */
+  switch(sum)
+    {
+    /* No printing option has been called, so just return. */
+    case 0:  return;
 
-        case GAL_OPTIONS_KEY_SETDIRCONF:
-          asprintf(&dirname, ".%s", PACKAGE);
-          options_print_all(cp, dirname, cp->coptions[i].name);
-          free(dirname);
-          break;
+    /* (Only) one of the printing options has been called, so we'll need to
+       print the values in the proper place. */
+    case 1:
+      for(i=0; !gal_options_is_last(&cp->coptions[i]); ++i)
+        if(cp->coptions[i].set && OPTIONS_UINT8VAL)
+          switch(cp->coptions[i].key)
+            {
+            case GAL_OPTIONS_KEY_PRINTPARAMS:
+              options_print_all(cp, NULL, NULL);
+              break;
 
-        case GAL_OPTIONS_KEY_SETUSRCONF:
-          home=options_get_home();
-          asprintf(&dirname, "%s/%s", home, USERCONFIG_DIR);
-          options_print_all(cp, dirname, cp->coptions[i].name);
-          free(dirname);
-          break;
-        }
+            case GAL_OPTIONS_KEY_SETDIRCONF:
+              if( asprintf(&dirname, ".%s", PACKAGE)<0 )
+                error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
+              options_print_all(cp, dirname, cp->coptions[i].name);
+              free(dirname);
+              break;
+
+            case GAL_OPTIONS_KEY_SETUSRCONF:
+              home=options_get_home();
+              if( asprintf(&dirname, "%s/%s", home, USERCONFIG_DIR)<0 )
+                error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
+              options_print_all(cp, dirname, cp->coptions[i].name);
+              free(dirname);
+              break;
+            }
+      break;
+
+    /* More than one of the printing options has been called. */
+    default:
+      error(EXIT_FAILURE, 0, "only one of the `printparams', `setdirconf' "
+            "and `setusrconf' options can be called in each run");
+    }
 }
