@@ -3,9 +3,9 @@ txt -- functions to deal with plain text files.
 This is part of GNU Astronomy Utilities (Gnuastro) package.
 
 Original author:
-     Mohammad Akhlaghi <akhlaghi@gnu.org>
+     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 Contributing author(s):
-Copyright (C) 2016, Free Software Foundation, Inc.
+Copyright (C) 2016-2018, Free Software Foundation, Inc.
 
 Gnuastro is free software: you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
@@ -237,7 +237,7 @@ txt_info_from_comment(char *line, gal_data_t **datall, char *comm_start)
          are dealing with the string type, we have to pull out the number
          part first. If there is no number for a string type, then ignore
          the line. */
-      if(typestr)
+      if(typestr && *typestr!='\0')
         {
           typestr=txt_trim_space(typestr);
           if( !strncmp(typestr, "str", 3) )
@@ -546,7 +546,7 @@ txt_get_info(char *filename, int format, size_t *numdata, size_t *dsize)
   fp=fopen(filename, "r");
   if(fp==NULL)
     error(EXIT_FAILURE, errno, "%s: couldn't open to read as a plain "
-          "text %s in %s", filename, format_err, __func__);
+          "text %s (from Gnuastro's `%s')", filename, format_err, __func__);
 
 
   /* Allocate the space necessary to keep each line as we parse it. Note
@@ -856,7 +856,7 @@ txt_fill(char *line, char **tokens, size_t maxcolnum, gal_data_t *info,
 
 static gal_data_t *
 gal_txt_read(char *filename, size_t *dsize, gal_data_t *info,
-             gal_list_sizet_t *indexll, int minmapsize, int format)
+             gal_list_sizet_t *indexll, size_t minmapsize, int format)
 {
   FILE *fp;
   char *line;
@@ -1143,8 +1143,7 @@ txt_print_value(FILE *fp, void *array, int type, size_t ind, char *fmt)
 
 static FILE *
 txt_open_file_write_info(gal_data_t *datall, char **fmts,
-                         gal_list_str_t *comment, char *filename,
-                         int dontdelete)
+                         gal_list_str_t *comment, char *filename)
 {
   FILE *fp;
   gal_data_t *data;
@@ -1153,9 +1152,13 @@ txt_open_file_write_info(gal_data_t *datall, char **fmts,
   gal_list_str_t *strt;
   int nlen, nw=0, uw=0, tw=0, bw=0;
 
+  /* Make sure the file doesn't already eixist. */
+  if( gal_checkset_check_file_return(filename) )
+    error(EXIT_FAILURE, 0, "%s: %s already exists. For safety, this "
+          "function will not over-write an existing file. Please delete "
+          "it before calling this function", __func__, filename);
 
-  /* Check the file and open it. */
-  gal_checkset_writable_remove(filename, 0, dontdelete);
+  /* Open the output file. */
   errno=0;
   fp=fopen(filename, "w");
   if(fp==NULL)
@@ -1203,7 +1206,8 @@ txt_open_file_write_info(gal_data_t *datall, char **fmts,
      over-write the one that `sprintf' puts with a `:' for the columns
      that have the same number of digits as the final column. */
   i=0;
-  asprintf(&nstr, "%zu:", num);
+  if( asprintf(&nstr, "%zu:", num)<0 )
+    error(EXIT_FAILURE, 0, "%s: asprintf allocation", __func__);
   nlen=strlen(nstr);
   for(data=datall; data!=NULL; data=data->next)
     {
@@ -1235,14 +1239,16 @@ txt_open_file_write_info(gal_data_t *datall, char **fmts,
 
 
 void
-gal_txt_write(gal_data_t *input, gal_list_str_t *comment, char *filename,
-              int dontdelete)
+gal_txt_write(gal_data_t *input, gal_list_str_t *comment, char *filename)
 {
   FILE *fp;
   char **fmts;
   size_t i, j, num=0, fmtlen;
   gal_data_t *data, *next2d=NULL;
 
+  /* Make sure input is valid. */
+  if(input==NULL) error(EXIT_FAILURE, 0, "%s: input is NULL", __func__);
+
 
   /* Currently only 1 and 2 dimension datasets are acceptable. */
   if( input->ndim!=1 && input->ndim!=2 )
@@ -1270,7 +1276,7 @@ gal_txt_write(gal_data_t *input, gal_list_str_t *comment, char *filename,
 
       /* Check if the dimensionality and size is the same for all the
          elements. */
-      if( input!=data && gal_data_dsize_is_different(input, data) )
+      if( input!=data && gal_dimension_is_different(input, data) )
         error(EXIT_FAILURE, 0, "%s: the input list of datasets must have the "
               "same sizes (dimentionality and length along each dimension)",
               __func__);
@@ -1285,8 +1291,7 @@ gal_txt_write(gal_data_t *input, gal_list_str_t *comment, char *filename,
   /* Set the output FILE pointer: if it isn't NULL, its an actual file,
      otherwise, its the standard output. */
   fp = ( filename
-         ? txt_open_file_write_info(input, fmts, comment, filename,
-                                    dontdelete)
+         ? txt_open_file_write_info(input, fmts, comment, filename)
          : stdout );
 
 
