@@ -4,7 +4,7 @@
 # (in the Installing gnuastro section).
 #
 # Original author:
-#     Mohammad Akhlaghi <akhlaghi@gnu.org>
+#     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 # Contributing author(s):
 #
 # Copying and distribution of this file, with or without modification,
@@ -19,7 +19,7 @@
 # Preliminaries
 # =============
 #
-# Set the variabels (The executable is in the build tree). Do the
+# Set the variables (The executable is in the build tree). Do the
 # basic checks to see if the executable is made or if the defaults
 # file exists (basicchecks.sh is in the source tree).
 img=psf.fits
@@ -42,9 +42,9 @@ execname=../bin/$prog/ast$prog
 #     data file failed).
 #
 #   - libjpeg was not present on the system.
-if [ ! -f $execname ] || [ ! -f $img ] || [ "x$haslibjpeg" != "xyes" ]; then
-    exit 77;
-fi
+if [ ! -f $execname           ];then echo "$execname not created.";exit 77;fi
+if [ ! -f $img                ];then echo "$img does not exist.";  exit 77;fi
+if [ "x$haslibjpeg" != "xyes" ];then echo "libjpeg not present.";  exit 77;fi
 
 
 
@@ -53,4 +53,4 @@ fi
 
 # Actual test script
 # ==================
-$execname blank $img blank --output=blankch.jpg --noinvert
+$execname blank $img blank --output=blankch.jpg
