@@ -16,7 +16,7 @@
 #      build directories) so if you need to make lots of temporary test
 #      files, there they won't get mixed up with non-output files.
 #
-# Combined with the `tmpfs-config-make', this script can be used to greatly
+# Combined with the `developer-build', this script can be used to greatly
 # simplify the development process. After running that script once, for
 # subsequent builds during your development, you can run this script from
 # the top source directory (by running `./tests/during-dev.sh', or giving
@@ -39,9 +39,9 @@
 # this file.
 #
 # Original author:
-#     Mohammad Akhlaghi <akhlaghi@gnu.org>
+#     Mohammad Akhlaghi <mohammad@akhlaghi.org>
 # Contributing author(s):
-# Copyright (C) 2016, Free Software Foundation, Inc.
+# Copyright (C) 2016-2018, Free Software Foundation, Inc.
 #
 # Gnuastro is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free
@@ -65,7 +65,7 @@
 # Set the basic test directories. If you are building over the source
 # directory, then set `builddir' to `./'. If you want the outputs to be in
 # the top source directory, set it to `./'. Since 'build' is the assumed
-# symbolic link in `tmpfs-config-make', it is also assumed in the version
+# symbolic link in `developer-build', it is also assumed in the version
 # controlled version of this script. Note, if your directory names have
 # space characters in them, quote the full value
 numjobs=8
@@ -140,13 +140,23 @@ if make -j$numjobs -C "$builddir"; then
     # the last line in the configuration file doesn't actualy end with a
     # new line (in which case the appended string will be added to the end
     # of the last line).
-    cp "$srcdir/bin/gnuastro.conf" "$srcdir/bin/$utilname/ast$utilname.conf" \
-       .gnuastro/
+    if [ $utilname = buildprog ]; then
+        extraopts="--la=$builddir/lib/libgnuastro.la"
+        extraopts="$extraopts -I$srcdir/lib -L$builddir/lib"
+        topconfdir="$builddir"
+    else
+        topconfdir="$srcdir"
+    fi
+    cp "$srcdir/bin/gnuastro.conf"                                    \
+       "$topconfdir/bin/$utilname/ast$utilname.conf" .gnuastro/
+
+    # Append `lastconfig' option to `gnuastro.conf', so the program doesn't
+    # go into the system headers.
     echo ""               >> .gnuastro/gnuastro.conf
     echo " lastconfig 1"  >> .gnuastro/gnuastro.conf
 
     # Run the built utility with the given arguments and options.
-    "$utility" $arguments $options
+    "$utility" $arguments $options $extraopts
 
     # Clean up.
     rm -rf .gnuastro
